@@ -16,4 +16,4 @@ class Command(BaseCommand):
             raise CommandError('Need a controller name as an argument')
         for controller_name in args:
             generate_controller(dir, controller_name)
-            self.stdout.write('Successfully initialized service "%s"' % controller_name)
+            self.stdout.write('Successfully initialized controller "%s"' % controller_name)
